pub fn run_file(
options: RunOptions,
content: &str,
fullpath: &Path,
) -> Result<(), Vec<Box<dyn ReportableError>>>Expand description
Compile and run a single source file according to the provided options.
pub fn run_file(
options: RunOptions,
content: &str,
fullpath: &Path,
) -> Result<(), Vec<Box<dyn ReportableError>>>Compile and run a single source file according to the provided options.